#ifndef MAXWELL_SAMPLE
#define MAXWELL_SAMPLE
#include <string>

#include "epix.h"
const double Temp(1173.15); // default temperature

// Represent a sample of specified color, name, mass, and temperature
class sample {
public:
  // e.g. sample(Red(), "He", 0.004, 273.15) or sample(Blue(), "Al", "0.0270")
  sample(const ePiX::Color& color,
	 const std::string& name, double Mx, double Tx = Temp);

  void plot(double Tmin, double Tmax, unsigned int num_pts) const;

  // return approximate top right corner of smallest bounding rectangle
  ePiX::P TR(double Tmin, double Tmax) const;

private:
  const ePiX::Color m_color;
  const std::string m_name; // element name/symbol
  const double m_Mx;        // Molar mass of sample
  const double m_Tx;        // temperature (K)

  // label/peak location
  mutable double vmp;
  mutable double fvmp;

  static const double k;    // Boltzmann's constant

  // functions for internal use
  double boltzmann() const;

  inline double rescale(double T) const
  {
    // if using angular velocity of a measuring device,
    // modify to calculate T based on distance and angular
    // velocity in rad, e.g. multiply T by 0.262/(M_PI/6);
    return T;
  }

  void label() const;

}; // end of sample class

#endif /* MAXWELL_SAMPLE */
